@@ -6,7 +6,7 @@ use FFI::Platypus;
 use base qw( Exporter );
 
 # ABSTRACT: Memory functions for FFI
-our $VERSION = '0.43'; # VERSION
+our $VERSION = '0.44'; # VERSION
 
 
 our @EXPORT = qw( malloc free calloc realloc memcpy memset strdup );
@@ -22,15 +22,28 @@ $ffi->attach(realloc => ['opaque', 'size_t']           => 'opaque' => '$$');
 $ffi->attach(memcpy  => ['opaque', 'opaque', 'size_t'] => 'opaque' => '$$$');
 $ffi->attach(memset  => ['opaque', 'int', 'size_t']    => 'opaque' => '$$$');
 
-eval { $ffi->attach(strdup  => ['string'] => 'opaque' => '$') };
+# This global may be removed at any time, do not use it
+# externally.  It is used by t/ffi_platypus_memory__strdup.t
+# for a diagnostic.
+our $_strdup_impl = 'not-loaded';
+
+eval {
+  die "do not use c impl" if ($ENV{FFI_PLATYPUS_MEMORY_STRDUP_IMPL}||'c') eq 'perl';
+  $ffi->attach(strdup  => ['string'] => 'opaque' => '$');
+};
 if($@)
 {
+  $_strdup_impl = 'perl';
   *strdup = sub ($) {
     my($string) = @_;
     my $ptr = malloc(length($string)+1);
     memcpy($ptr, $ffi->cast('string' => 'opaque', $string), length($string)+1);
   };
 }
+else
+{
+  $_strdup_impl = 'c';
+}
 
 1;
 
@@ -46,7 +59,7 @@ FFI::Platypus::Memory - Memory functions for FFI
 
 =head1 VERSION
 
-version 0.43
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -132,6 +145,28 @@ Platforms that do not support C<strdup> will be provided with an
 equivalent using C<malloc> and C<memcpy> written in Perl.  This version 
 is slower.
 
+=head1 ENVIRONMENT
+
+=head2 FFI_PLATYPUS_MEMORY_STRDUP_IMPL
+
+C<strdup> isn't always supported by all platforms.  On platforms that do not support
+it, it is emulated using calls to C<malloc> and C<memcpy> which are part of the
+standard C library.  Because this requires two function calls it is probably not
+as fast on most platforms.
+
+If you experience problems with the C<strdup> provided by your platform, you can
+force the emulated implementation using the FFI_PLATYPUS_MEMORY_STRDUP_IMPL
+environment variable.
+
+ # bash:
+ $ export FFI_PLATYPUS_MEMORY_STRDUP_IMPL=perl
+
+ # tcsh:
+ % setenv FFI_PLATYPUS_MEMORY_STRDUP_IMPL perl
+
+ # Windows:
+ > SET FFI_PLATYPUS_MEMORY_STRDUP_IMPL=perl
+
 =head1 SEE ALSO
 
 =over 4
