@@ -12,7 +12,7 @@ use FFI::Platypus::Buffer qw( scalar_to_buffer );
 use FFI::Platypus::Buffer qw( buffer_to_scalar );
 
 # ABSTRACT: Convert string scalar to a buffer as a pointer / size_t combination
-our $VERSION = '0.42'; # VERSION
+our $VERSION = '0.44'; # VERSION
 
 
 my @stack;
@@ -60,7 +60,7 @@ FFI::Platypus::Type::PointerSizeBuffer - Convert string scalar to a buffer as a
 
 =head1 VERSION
 
-version 0.42
+version 0.44
 
 =head1 SYNOPSIS
 
@@ -74,11 +74,12 @@ In your C code:
 
 In your Platypus::FFI code:
 
- use FFI::Platypus::Declare
-   'void',
-   [ '::PointerSizeBuffer' => 'buffer' ];
+ use FFI::Platypus;
  
- attach function_with_buffer => [buffer] => void;
+ my $ffi = FFI::Platypus->new;
+ $ffi->load_custom_type('::PointerSizeBuffer' => 'buffer');
+ 
+ $ffi->attach(function_with_buffer => ['buffer'] => 'void');
  my $string = "content of buffer";
  function_with_buffer($string);
 
@@ -98,10 +99,6 @@ pass in a string scalar as a pointer / size buffer pair.
 
 Main Platypus documentation.
 
-=item L<FFI::Platypus::Declare>
-
-Declarative interface for Platypus.
-
 =item L<FFI::Platypus::Type>
 
 Platypus types documentation.
@@ -126,6 +123,8 @@ Fitz Elliott (felliott)
 
 Vickenty Fesunov (vyf)
 
+Gregor Herrmann (gregoa)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Graham Ollis.
